@@ -7,7 +7,12 @@ def decibelm_to_watts(dbm_value: float) -> float:
     return 10 ** ((dbm_value - 30) / 10)
 
 
-def format_exponent_as_str(number_to_format: float, decimals: int = 2) -> str:
+def format_exponent_as_str(
+        number_to_format: float,
+        decimals: int = 2,
+        separator=r"\cdot",
+        only_exp: bool = False
+) -> str:
     """
     Format an exponent as a LaTeX string
     e.g. 0.0001 will be formatted as $1.0 \times 10^{-4}$
@@ -23,10 +28,22 @@ def format_exponent_as_str(number_to_format: float, decimals: int = 2) -> str:
             number_to_format *= 10
             count -= 1
 
-    formatted_str = r"${{ {} }} \times 10^{{ {} }}$".format(round(number_to_format, decimals), count)
+    if only_exp:
+        formatted_str = r"$10^{{ {} }}$".format(count)
+    else:
+        if decimals == 0:
+            formatted_str = r"${{ {} }} {} 10^{{ {} }}$".format(int(number_to_format), separator, count)
+        else:
+            formatted_str = r"${{ {} }} {} 10^{{ {} }}$".format(round(number_to_format, decimals), separator, count)
+
     return formatted_str
 
 
+def log_tick_formatter(val, pos=None):
+    """ Format ticks for log10 scale plots """
+    return rf"$10^{{{val:.0f}}}$"
+
+
 def baseline_als(y: np.ndarray, lam: float = 1e6, p: float = 0.9, niter: int = 10) -> np.ndarray:
     """
     Asymmetric least squares baseline.
